@@ -37,15 +37,15 @@ class DeviceInfo:
         """Update device information from a decoded FlatBuffer packet."""
         # Update device model
         if device_state.Model():
-            self.device_model = device_state.Model()
+            self.device_model = device_state.Model().decode('utf-8')
         
         # Update nickname
         if device_state.Nickname() and device_state.Nickname().Value():
-            self.nickname = device_state.Nickname().Value()
+            self.nickname = device_state.Nickname().Value().decode('utf-8')
         
         # Update MAC address from network info
         if device_state.Network() and device_state.Network().MacAddress():
-            self.mac_address = device_state.Network().MacAddress()
+            self.mac_address = device_state.Network().MacAddress().decode('utf-8')
         
         # Update last seen timestamp
         self.last_seen = time.time()
@@ -213,13 +213,12 @@ class PixelAirClient:
         
         self.logger.info("PixelAirClient stopped")
     
-    def register_device(self, ip_address: str, device_id: Optional[str] = None) -> bool:
+    def register_device(self, ip_address: str) -> bool:
         """
         Register a device in the client registry (creates PixelAirDevice instance).
         
         Args:
             ip_address: IP address of the device to register
-            device_id: Optional device identifier
             
         Returns:
             True if registered successfully, False if already exists
@@ -230,7 +229,7 @@ class PixelAirClient:
                 return False
             
             # Create PixelAirDevice instance directly (no more circular import)
-            device = PixelAirDevice(ip_address, device_id)
+            device = PixelAirDevice(ip_address)
             self.devices[ip_address] = device
             self.logger.info(f"Registered PixelAir device: {device}")
             return True
@@ -387,14 +386,13 @@ class PixelAirClient:
             'devices': [device.to_dict() for device in devices]
         }
     
-    def _track_discovered_device(self, ip_address: str, device_id: Optional[str] = None, 
+    def _track_discovered_device(self, ip_address: str, 
                                 device_state: Optional[PixelAirDeviceFB] = None) -> DeviceInfo:
         """
         Track a discovered device (does NOT auto-register it).
         
         Args:
-            ip_address: IP address of the device
-            device_id: Optional device identifier
+            ip_address: IP address of the device (used as the device identifier)
             device_state: Optional decoded device state for extracting additional info
             
         Returns:
@@ -405,8 +403,6 @@ class PixelAirClient:
                 # Update existing discovery info
                 device_info = self.discovered_devices[ip_address]
                 device_info.last_seen = time.time()
-                if device_id and not device_info.device_id:
-                    device_info.device_id = device_id
                 
                 # Update from packet data if available
                 if device_state:
@@ -416,7 +412,6 @@ class PixelAirClient:
                 device_info = DeviceInfo(
                     ip_address=ip_address,
                     last_seen=time.time(),
-                    device_id=device_id
                 )
                 
                 # Update from packet data if available
@@ -425,8 +420,7 @@ class PixelAirClient:
                 
                 self.discovered_devices[ip_address] = device_info
                 self.logger.debug(f"Discovered new device: {ip_address} "
-                                f"(id: {device_id or 'unknown'}, "
-                                f"model: {device_info.device_model or 'unknown'}, "
+                                f"(model: {device_info.device_model or 'unknown'}, "
                                 f"nickname: {device_info.nickname or 'none'})")
         
         return device_info
